/*-------------------------------------------------------------------------+
| Copyright 2020 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.introspection;

import org.fortiss.tooling.kernel.introspection.IIntrospectionDetailsItem;
import org.fortiss.tooling.kernel.introspection.IIntrospectionItem;
import org.fortiss.tooling.kernel.introspection.IIntrospectiveKernelService;
import org.fortiss.tooling.kernel.ui.introspection.details.DetailsUIHandlerBase;
import org.fortiss.tooling.kernel.ui.introspection.details.KISSDetailsUIRegistry;

import javafx.fxml.FXML;
import javafx.scene.Node;
import javafx.scene.control.Label;
import javafx.scene.layout.BorderPane;
import javafx.scene.layout.VBox;

public class KISSServicesFXController extends KISSCompositeFXController<VBox> {

	@FXML
	private VBox vBox;

	/** The description label at the bottom. */
	private Label description;

	/** The greeting text. */
	static final String GREETING =
			"Welcome to KISS!\n\nThis is the kernel introspection system service.";

	/** {@inheritDoc} */
	@Override
	public String getFXMLLocation() {
		return "KISSServices.fxml";
	}

	/** {@inheritDoc} */
	@Override
	public void initialize() {
		description = new Label();
		description.setText(GREETING);
		vBox.setStyle("-fx-padding: 5;" + "-fx-border-style: solid inside;" +
				"-fx-border-width: 2;" + "-fx-border-insets: 5;" + "-fx-border-radius: 5;" +
				"-fx-border-color: lightblue;");
		vBox.getChildren().add(description);
	}

	/** {@inheritDoc} */
	@Override
	public void changed(BorderPane borderPane, IIntrospectionItem selection) {
		Node center = new Label("No details available!");
		String descr = GREETING;
		if(selection instanceof IIntrospectiveKernelService) {
			IIntrospectiveKernelService ks = (IIntrospectiveKernelService)selection;
			descr = ks.getIntrospectionDescription();
			IIntrospectionDetailsItem item = ks.getDetailsItem();
			if(item != null) {
				DetailsUIHandlerBase handler =
						KISSDetailsUIRegistry.getInstance().getHandler(item.getClass());
				if(handler != null) {
					handler.setService(ks);
					handler.setDataItem(item);
					center = handler.createDisplayControl();
				}
			}
		}
		description.setText(descr);
		borderPane.setCenter(center);
	}
}
